@@ -783,6 +783,7 @@ static void init_GetPrivateKey(server_rec *s, pool *p, SSLConfigRec *pConfig,
 {
     RSA *prsaKey;
     FILE *fp;
+    int n, rc;
 
     if (g_pKeyTable == NULL) {
         if ((g_pKeyTable = ap_make_table(g_pPermanentPool, 10)) == NULL) {
@@ -806,7 +807,19 @@ static void init_GetPrivateKey(server_rec *s, pool *p, SSLConfigRec *pConfig,
     }
 
     pConfig->prsaKey = RSA_new();
-    if (!__SSLeay PEM_read_RSAPrivateKey(fp, &pConfig->prsaKey, NULL)) {
+    for (n = 0; n <= 3; n++) {
+        rc = (__SSLeay PEM_read_RSAPrivateKey(fp, &pConfig->prsaKey, NULL) != NULL);
+        if (!rc && ERR_peek_error() == 
+                   ERR_PACK(ERR_LIB_EVP,EVP_F_EVP_DECRYPTFINAL,EVP_R_BAD_DECRYPT)) {
+            fprintf(stderr, "bad pass phrase "
+                            "(%d more retr%s permitted).\n",
+                            3-n, (3-n) == 1 ? "y" : "ies");
+            (void)fseek(fp, 0, SEEK_SET);
+            continue;
+        }
+        break;
+    }
+    if (!rc) {
         ap_log_error(APLOG_MARK, APLOG_CRIT, s,
                     "mod_ssl: Failed to read private key file %s", szKeyFile);
         ssl_log_ssleay2apache(s);
