@@ -136,7 +136,7 @@ char *get_time(void)
 
     t = time(NULL);
     time_string = ctime(&t);
-    time_string[strlen(time_string) - 1] = '\0';
+    time_string[strlen(time_string)-1] = '\0';
     return (time_string);
 }
 
@@ -147,15 +147,17 @@ static void HandleAdd(int nFD)
     Cache *p;
 
     aucKey = ReadThing(nFD, &nKey);
-    p = LocalCacheFind(aucKey, nKey);
-    if (p) {
+    if (aucKey == NULL)
+        return;
+    if ((p = LocalCacheFind(aucKey, nKey)) != NULL) {
         free(p->aucData);
         free(aucKey);
     }
-    else
+    else {
         p = LocalCacheAdd(aucKey, nKey, 0);
+    }
     p->aucData = ReadThing(nFD, &p->nData);
-    read(nFD, &p->tExpiresAt, sizeof p->tExpiresAt);
+    read(nFD, &p->tExpiresAt, sizeof(p->tExpiresAt));
 }
 
 void HandleGet(int nFD)
@@ -165,30 +167,33 @@ void HandleGet(int nFD)
     Cache *p;
 
     aucKey = ReadThing(nFD, &nKey);
-    p = LocalCacheFind(aucKey, nKey);
-    if (!p) {
+    if (aucKey == NULL)
+        return;
+    if ((p = LocalCacheFind(aucKey, nKey)) == NULL) { 
         WriteThing(nFD, NULL, 0);
     }
     else {
         WriteThing(nFD, p->aucData, p->nData);
-        write(nFD, &p->tExpiresAt, sizeof p->tExpiresAt);
+        write(nFD, &p->tExpiresAt, sizeof(p->tExpiresAt));
     }
+    return;
 }
 
 void HandleClient(int nFD)
 {
     static char c;
 
-    read(nFD, &c, 1);
+    if (read(nFD, &c, 1) != 1)
+        return;
     switch (c) {
-    case ADD_TO_CACHE:
-        HandleAdd(nFD);
-        break;
-
-    case GET_FROM_CACHE:
-        HandleGet(nFD);
-        break;
+        case ADD_TO_CACHE:
+            HandleAdd(nFD);
+            break;
+        case GET_FROM_CACHE:
+            HandleGet(nFD);
+            break;
     }
+    return;
 }
 
 void signal_handler(int sig)
@@ -207,9 +212,12 @@ int main(int argc, char **argv)
     SockAddr saServer;
     int one = 1;
     int nSize;
+    int nFD;
+    int nLen;
+    SockAddr saClient;
 
     if (argc != 3) {
-        fprintf(stderr, "%s <user id> <port>\n", argv[0]);
+        fprintf(stderr, "%s <user id> <port_or_file>\n", argv[0]);
         exit(1);
     }
 
@@ -220,9 +228,8 @@ int main(int argc, char **argv)
     signal(SIGTERM, signal_handler);
 
     nUserID = atoi(argv[1]);
-    szPort = argv[2];
-
-    nPort = atoi(szPort);
+    szPort  = argv[2];
+    nPort   = atoi(szPort);
 
     if (nPort)
         nSocket = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
@@ -246,15 +253,15 @@ int main(int argc, char **argv)
         nSize = sizeof saServer.in;
     }
     else {
-        if (strlen(szPort) >= sizeof saServer.un.sun_path)
+        if (strlen(szPort) >= sizeof(saServer.un.sun_path))
             exit(6);
         saServer.un.sun_family = AF_UNIX;
         unlink(szPort);
         strcpy(saServer.un.sun_path, szPort);
-        nSize = sizeof saServer.un;
+        nSize = sizeof(saServer.un);
     }
 
-    if (bind(nSocket, (struct sockaddr *) &saServer, nSize) < 0) {
+    if (bind(nSocket, (struct sockaddr *)&saServer, nSize) < 0) {
         perror("bind");
         exit(3);
     }
@@ -276,10 +283,6 @@ int main(int argc, char **argv)
     }
 
     for (;;) {
-        int nFD;
-        int nLen;
-        SockAddr saClient;
-
         nLen = nSize;
         nFD = accept(nSocket, (struct sockaddr *) &saClient, &nLen);
         if (nFD < 0) {
@@ -296,7 +299,6 @@ int main(int argc, char **argv)
 
         close(nFD);
     }
-
-    return 0;
+    return (0);
 }
 
